import objectdraw.*;
import java.awt.*;

/*
 * Example DrinkMug: a custom class representing a refreshing
 * mug of some beverage.  It is capable of many things.
 *
 * Jim Teresco, The College of Saint Rose, CSC 252, Fall 2015
 *
 * $Id: DrinkMug.java 2717 2015-09-29 17:07:09Z terescoj $
 */

public class DrinkMug {

    private static final double WIDTH = 50;
    private static final double HEIGHT = 100;
    private static final double HANDLE = 20;
    private static final double THICKNESS = 5;
    
    private FilledRect background;
    private FilledOval handle;
    private FilledRect contents;
    
    public DrinkMug(Location position, DrawingCanvas c) {
        
        background = new FilledRect(position, WIDTH, HEIGHT, c);
        handle = new FilledOval(position.getX() + WIDTH - HANDLE / 2,
                                position.getY() + (HEIGHT - HANDLE)/ 2,
                                HANDLE, HANDLE, c);
        contents = new FilledRect(position.getX() + THICKNESS,
                                  position.getY() + HEIGHT - THICKNESS*2,
                                  WIDTH - THICKNESS*2, 0, c);
        contents.setColor(Color.white);
    }
    
    public boolean contains(Location point) {
        
        return background.contains(point) || handle.contains(point);
        
    }
    
    public void move(double dx, double dy) {
        
        background.move(dx, dy);
        contents.move(dx, dy);
        handle.move(dx, dy);
    }
    
    // check if any component here overlaps with the given object
    public boolean overlaps(Drawable2DInterface other) {
        
        return other.overlaps(background) || other.overlaps(handle);
    }
    
    // fill it up!
    public void fill() {
        
        contents.setHeight(HEIGHT-THICKNESS);
        contents.moveTo(contents.getX(), background.getY());
    }
    
    // chill
    public void chill() {
        
        if (contents.getHeight() > 0) {
            contents.setColor(Color.blue);
        }
    }
    
    // heat
    public void heat() {
        
        if (contents.getHeight() > 0) {
            contents.setColor(Color.red);
        }
    }
}
