
/**
 * Example DrinkMug: the window controller class for the DrinkMug
 * custom class example
 *
 * Developed partially in class by CSC 252 Fall 2015
 * 
 * @author Jim Teresco
 */

import objectdraw.*;
import java.awt.*;

public class DrinkMugGame extends WindowController
{

    private static final double FAUCET_SIZE = 40;
    
    private FilledRect fridge;
    private FilledRect stove;
    private DrinkMug mug1, mug2;
    private FilledRect stream;
    
    // support for dragging
    private DrinkMug draggingMug = null;
    private Location lastMouse;
    
    public void begin() 
    {
        double w = canvas.getWidth();
        double h = canvas.getHeight();
        
        // fridge and stove
        fridge = new FilledRect(2*w/3, 2*h/3, w/3, h/3, canvas);
        fridge.setColor(Color.blue);
        
        stove = new FilledRect(2*w/3, 0, w/3, w/3, canvas);
        stove.setColor(Color.red);
        
        // faucet
        new FilledRect(0, h/2, FAUCET_SIZE*2, FAUCET_SIZE, canvas);
        new FilledRect(FAUCET_SIZE, h/2 + FAUCET_SIZE, FAUCET_SIZE, FAUCET_SIZE, canvas);
        stream = new FilledRect(FAUCET_SIZE*1.33, h/2+2*FAUCET_SIZE, FAUCET_SIZE/3, 
            FAUCET_SIZE, canvas);
        stream.setColor(Color.blue);
        
        // mugs
        mug1 = new DrinkMug(new Location(50, 50), canvas);
        mug2 = new DrinkMug(new Location(200, 250), canvas);
    }

    // set up for standard dragging
    public void onMousePress(Location point) {
        
        if (mug1.contains(point)) {
            draggingMug = mug1;
        }
        else if (mug2.contains(point)) {
            draggingMug = mug2;
        }
        else {
            draggingMug = null;
        }
        lastMouse = point;
    }
    
    // standard dragging
    public void onMouseDrag(Location point) {
        
        if (draggingMug != null) {
            draggingMug.move(point.getX() - lastMouse.getX(),
                             point.getY() - lastMouse.getY());
            lastMouse = point;
        }
    }
    
    public void onMouseRelease(Location point) {
        
        if (draggingMug != null) {
	    // regular dragging move
            draggingMug.move(point.getX() - lastMouse.getX(),
                             point.getY() - lastMouse.getY());
                             
            // check for filling, heating, cooling
            if (draggingMug.overlaps(stream)) {
                draggingMug.fill();
            }
            
            if (draggingMug.overlaps(fridge)) {
                draggingMug.chill();
            }
            
            if (draggingMug.overlaps(stove)) {
                draggingMug.heat();
            }
        }
        
        draggingMug = null;
    }
}
